@@ -1,10 +1,10 @@
 import atexit
 import logging
-from typing import Any, Callable, Dict, List, Optional, Tuple, Union
+from typing import Any, Awaitable, Callable, Dict, List, Optional
 
 from motion.execute import Executor
 from motion.route import Route
-from motion.utils import DEFAULT_KEY_TTL, FitEventGroup, configureLogging, logger
+from motion.utils import DEFAULT_KEY_TTL, configureLogging, logger
 
 
 def is_logger_open(logger: logging.Logger) -> bool:
@@ -27,9 +27,10 @@ class ComponentInstance:
         init_state_params: Optional[Dict[str, Any]],
         save_state_func: Optional[Callable],
         load_state_func: Optional[Callable],
-        infer_routes: Dict[str, Route],
-        fit_routes: Dict[str, List[Route]],
+        serve_routes: Dict[str, Route],
+        update_routes: Dict[str, List[Route]],
         logging_level: str = "WARNING",
+        disabled: bool = False,
     ):
         """Creates a new instance of a Motion component.
 
@@ -53,28 +54,36 @@ class ComponentInstance:
         self._instance_name = instance_name
 
         self.running = False
+        self.disabled = disabled
         self._executor = Executor(
             self._instance_name,
             init_state_func=init_state_func,
             init_state_params=init_state_params if init_state_params else {},
             save_state_func=save_state_func,
             load_state_func=load_state_func,
-            infer_routes=infer_routes,
-            fit_routes=fit_routes,
+            serve_routes=serve_routes,
+            update_routes=update_routes,
+            disabled=self.disabled,
         )
         self.running = True
 
     @property
     def instance_name(self) -> str:
         """Component name with a random phrase to represent
-        the name of this instance."""
+        the name of this instance.
+        In the form of componentname__randomphrase.
+        """
         return self._instance_name
 
+    @property
+    def instance_id(self) -> str:
+        """Latter part of the instance name, which is a random phrase
+        or a user-defined ID."""
+        return self._instance_name.split("__")[-1]
+
     def shutdown(self) -> None:
         """Shuts down a Motion component instance, saving state.
-
-        Warning: if you don't shutdown a component instance when you are
-        finished using it, your program may infinitely hang!
+        Automatically called when the instance is garbage collected.
 
         Usage:
         ```python
@@ -86,14 +95,18 @@ class ComponentInstance:
         def setUp():
             return {"value": 0}
 
-        # Define infer and fit operations
+        # Define serve and update operations
 
-        c_instance = C()
-        c_instance.run(...)
-        c_instance.run(...)
-        c_instance.shutdown()
+        if __name__ == "__main__":
+            c_instance = C()
+            c_instance.run(...)
+            c_instance.run(...)
+            c_instance.shutdown()
         ```
         """
+        if self.disabled:
+            return
+
         if not self.running:
             return
 
@@ -109,7 +122,7 @@ class ComponentInstance:
     def get_version(self) -> int:
         """
         Gets the state version (might be outdated) currently being
-        used for infer ops.
+        used for serve ops.
 
         Usage:
         ```python
@@ -121,19 +134,20 @@ class ComponentInstance:
         def setUp():
             return {"value": 0}
 
-        # Define infer and fit operations
+        # Define serve and update operations
 
-        c_instance = C()
-        c_instance.get_version() # Returns 1 (first version)
+        if __name__ == "__main__":
+            c_instance = C()
+            c_instance.get_version() # Returns 1 (first version)
         ```
         """
         return self._executor.version  # type: ignore
 
-    def update_state(self, state_update: Dict[str, Any]) -> None:
+    def write_state(self, state_update: Dict[str, Any]) -> None:
         """Writes the state update to the component instance's state.
-        If a fit op is currently running, the state update will be
-        applied after the fit op is finished. Warning: this could
-        take a while if your fit op takes a long time!
+        If a update op is currently running, the state update will be
+        applied after the update op is finished. Warning: this could
+        take a while if your update ops take a long time!
 
         Usage:
         ```python
@@ -145,13 +159,13 @@ class ComponentInstance:
         def setUp():
             return {"value": 0}
 
-        # Define infer and fit operations
+        # Define serve and update operations
         ...
 
         if __name__ == "__main__":
             c_instance = C()
             c_instance.read_state("value") # Returns 0
-            c_instance.update_state({"value": 1, "value2": 2})
+            c_instance.write_state({"value": 1, "value2": 2})
             c_instance.read_state("value") # Returns 1
             c_instance.read_state("value2") # Returns 2
         ```
@@ -175,7 +189,7 @@ class ComponentInstance:
         def setUp():
             return {"value": 0}
 
-        # Define infer and fit operations
+        # Define serve and update operations
         ...
 
         if __name__ == "__main__":
@@ -194,14 +208,11 @@ class ComponentInstance:
         """
         return self._executor._loadState()[key]
 
-    def flush_fit(self, dataflow_key: str) -> None:
-        """Flushes the fit queue corresponding to the dataflow
+    def flush_update(self, dataflow_key: str) -> None:
+        """Flushes the update queue corresponding to the dataflow
         key, if it exists, and updates the instance state.
         Warning: this is a blocking operation and could take
-        a while if your fit op takes a long time!
-
-        The fit queue will be flushed even if there aren't
-        the predefined batch_size number of elements.
+        a while if your update op takes a long time!
 
         Example Usage:
         ```python
@@ -213,43 +224,52 @@ class ComponentInstance:
         def setUp():
             return {"value": 0}
 
-        @C.infer("add")
+        @C.serve("add")
         def add(state, value):
             return state["value"] + value
 
-        @C.fit("add", batch_size=2)
-        def add(state, values, infer_results):
-            return {"value": state["value"] + sum(values)}
+        @C.update("add")
+        def add(state, value, serve_result):
+            return {"value": state["value"] + value}
 
-        @C.infer("multiply")
+        @C.serve("multiply")
         def multiply(state, value):
             return state["value"] * value
 
-        c = C() # Create instance of C
-        c.run(add=1)
-        c.flush_fit("add") # (1)!
-        c.run(add=2) # This will use the updated state
+        if __name__ == "__main__":
+            c = C() # Create instance of C
+            c.run("add", kwargs={"value": 1})
+            c.flush_update("add") # (1)!
+            c.run("add", kwargs={"value": 2}) # This will use the updated state
 
-        # 1. Runs the fit op even though only one element is in the batch
+        # 1. Waits for the update op to finish, then updates the state
         ```
 
         Args:
             dataflow_key (str): Key of the dataflow.
+
+        Raises:
+            RuntimeError: If the component instance was initialized to
+            be disabled.
         """
-        self._executor.flush_fit(dataflow_key)
+        if self.disabled:
+            raise RuntimeError("Cannot run a disabled component instance.")
+
+        self._executor.flush_update(dataflow_key)
 
     def run(
         self,
-        *,
+        # *,
+        dataflow_key: str,
+        kwargs: Dict[str, Any] = {},
         cache_ttl: int = DEFAULT_KEY_TTL,
+        ignore_cache: bool = False,
         force_refresh: bool = False,
-        flush_fit: bool = False,
-        **kwargs: Any,
-    ) -> Union[Any, Tuple[Any, FitEventGroup]]:
-        """Runs the dataflow (infer and fit ops) for the keyword argument
+        flush_update: bool = False,
+    ) -> Any:
+        """Runs the dataflow (serve and update ops) for the keyword argument
         passed in. If the key is not found to have any ops, an error
-        is raised. Only one keyword argument should be passed in.
-        Fit ops are only executed when the batch size is reached.
+        is raised. Only one dataflow key should be passed in.
 
         Example Usage:
         ```python
@@ -261,73 +281,146 @@ class ComponentInstance:
         def setUp():
             return {"value": 0}
 
-        @C.infer("add")
+        @C.serve("add")
         def add(state, value):
             return state["value"] + value
 
-        @C.fit("add", batch_size=2)
-        def add(state, values, infer_results):
-            return {"value": state["value"] + sum(values)}
+        @C.update("add")
+        def add(state, value, serve_result):
+            return {"value": state["value"] + value}
 
-        @C.infer("multiply")
-        def multiply(state, value):
-            return state["value"] * value
+        if __name__ == "__main__":
+            c = C() # Create instance of C
+            c.run("add", kwargs={"value": 1}, flush_update=True) # (1)!
+            c.run("add", kwargs={"value": 1}) # Returns 1
+            c.run("add", kwargs={"value": 2}, flush_update=True) # (2)!
 
-        c = C() # Create instance of C
-        c.run(add=1, flush_fit=True) # (1)!
-        c.run(add=1) # Returns 1
-        c.run(add=2, flush_fit=True) # Returns 2, result state["value"] = 4
-        # Previous line called fit function and flushed fit queue
-        c.run(add=3) # No fit op runs since batch size = 1
-        c.run(multiply=2) # Returns 8 since state["value"] = 4
-        c.run(multiply=3, flush_fit=True) # (2)!
+            c.run("add", kwargs={"value": 3})
+            time.sleep(3) # Wait for the previous update op to finish
 
-        # 1. This forces the fit op to run even though the batch size
-        #   isn't reached, and waits for the fit op to finish running
-        # 2. This doesn't force or wait for any fit ops, since there are
-        #   no fit ops defined for `multiply`
+            c.run("add", kwargs={"value": 3}, force_refresh=True) # (3)!
+
+        # 1. Waits for the update op to finish, then updates the state
+        # 2. Returns 2, result state["value"] = 4
+        # 3. Force refreshes the state before running the dataflow, and
+        #    reruns the serve op even though the result might be cached.
         ```
 
 
         Args:
+            dataflow_key (str): Key of the dataflow to run.
+            kwargs (Dict[str, Any]): Keyword arguments to pass into the
+                dataflow ops, in addition to the state.
             cache_ttl (int, optional):
-                How long the inference result should live in a cache (in
-                seconds). Defaults to 1 day (60 * 60 * 24). The expiration
-                time is extended if there are subsequent infer calls
-                for the same value.
+                How long the serveence result should live in a cache (in
+                seconds). Defaults to 1 day (60 * 60 * 24).
+            ignore_cache (bool, optional):
+                If True, ignores the cache and runs the serve op. Does not
+                force refresh the state. Defaults to False.
             force_refresh (bool, optional): Read the latest value of the
-                state before running an inference call, otherwise a stale
+                state before running an serveence call, otherwise a stale
                 version of the state or a cached result may be used.
-                If you do not want to read from the cache, set force_refresh
-                = True. Defaults to False.
-            flush_fit (bool, optional):
-                If True, waits for the fit op to finish executing before
-                returning. If the fit queue hasn't reached batch_size
-                yet, the fit op runs anyways. Force refreshes the
-                state after the fit op completes. Defaults to False.
+                Defaults to False.
+            flush_update (bool, optional):
+                If True, waits for the update op to finish executing before
+                returning. If the update queue hasn't reached batch_size
+                yet, the update op runs anyways. Force refreshes the
+                state after the update op completes. Defaults to False.
+
+        Returns:
+            Any: Result of the serveence call. Might take a long time
+            to run if `flush_update = True` and the update operation is
+            computationally expensive.
+        """
+        if self.disabled:
+            raise RuntimeError("Cannot run a disabled component instance.")
+
+        serve_result = self._executor.run(
+            key=dataflow_key,
+            kwargs=kwargs,
+            cache_ttl=cache_ttl,
+            ignore_cache=ignore_cache,
+            force_refresh=force_refresh,
+            flush_update=flush_update,
+        )
+
+        return serve_result
+
+    async def arun(
+        self,
+        # *,
+        dataflow_key: str,
+        kwargs: Dict[str, Any] = {},
+        cache_ttl: int = DEFAULT_KEY_TTL,
+        ignore_cache: bool = False,
+        force_refresh: bool = False,
+        flush_update: bool = False,
+    ) -> Awaitable[Any]:
+        """Async version of run. Runs the dataflow (serve and update ops) for the
+        specified key.
+
+        Example Usage:
+        ```python
+        from motion import Component
+        import asyncio
+
+        C = Component("MyComponent")
+
+        @C.serve("sleep")
+        async def sleep(state, value):
+            await asyncio.sleep(value)
+            return "Slept!"
+
+        async def main():
+            c = C()
+            await c.arun("sleep", kwargs={"value": 1})
+
+        if __name__ == "__main__":
+            asyncio.run(main())
+        ```
+
+        Args:
+            dataflow_key (str): Key of the dataflow to run.
+            kwargs (Dict[str, Any]): Keyword arguments to pass into the
+                dataflow ops, in addition to the state.
+            cache_ttl (int, optional):
+                How long the serveence result should live in a cache (in
+                seconds). Defaults to 1 day (60 * 60 * 24).
+            ignore_cache (bool, optional):
+                If True, ignores the cache and runs the serve op. Does not
+                force refresh the state. Defaults to False.
+            force_refresh (bool, optional): Read the latest value of the
+                state before running an serveence call, otherwise a stale
+                version of the state or a cached result may be used.
+                Defaults to False.
+            flush_update (bool, optional):
+                If True, waits for the update op to finish executing before
+                returning. If the update queue hasn't reached batch_size
+                yet, the update op runs anyways. Force refreshes the
+                state after the update op completes. Defaults to False.
             **kwargs:
-                Keyword arguments for the infer and fit ops. You can only
+                Keyword arguments for the serve and update ops. You can only
                 pass in one pair.
 
         Raises:
             ValueError: If more than one dataflow key-value pair is passed.
+            RuntimeError: If the component instance was initialized to
+            be disabled.
 
         Returns:
-            Any: Result of the inference call. Might take a long time
-            to run if `flush_fit = True` and the fit operation is
-            computationally expensive.
+            Awaitable[Any]: Awaitable Result of the serveence call.
         """
-        if len(kwargs) != 1:
-            raise ValueError("Only one key-value pair is allowed in kwargs.")
+        if self.disabled:
+            raise RuntimeError("Cannot run a disabled component instance.")
 
-        key, value = next(iter(kwargs.items()))
-
-        infer_result = self._executor.run(
-            key=key,
-            value=value,
+        serve_result = await self._executor.arun(
+            key=dataflow_key,
+            kwargs=kwargs,
+            # value=value,
             cache_ttl=cache_ttl,
+            ignore_cache=ignore_cache,
             force_refresh=force_refresh,
-            flush_fit=flush_fit,
-        )
+            flush_update=flush_update,
+        )  # type: ignore
 
-        return infer_result
+        return serve_result  # type: ignore
