@@ -54,19 +54,19 @@ def clear_instance(instance_name: str) -> bool:
     ```
 
     Args:
-        instance (str): Instance name of the component to clear.
-            In the form `componentname__instancename`.
+        instance_name (str): Instance name of the component to clear.
+            In the form `componentname__instanceid`.
 
     Raises:
         ValueError:
             If the instance name is not in the form
-            `componentname__instancename`.
+            `componentname__instanceid`.
 
     Returns:
         bool: True if the instance existed, False otherwise.
     """
     if "__" not in instance_name:
-        raise ValueError("Instance must be in the form `componentname__instancename`.")
+        raise ValueError("Instance must be in the form `componentname__instanceid`.")
 
     rp = RedisParams()
     redis_con = redis.Redis(host=rp.host, port=rp.port, password=rp.password, db=rp.db)
@@ -103,19 +103,19 @@ def inspect_state(instance_name: str) -> Dict[str, Any]:
     ```
 
     Args:
-        instance (str): Instance name of the component to inspect.
-            In the form `componentname__instancename`.
+        instance_name (str): Instance name of the component to inspect.
+            In the form `componentname__instanceid`.
 
     Raises:
         ValueError:
             If the instance name is not in the form
-            `componentname__instancename` or if the instance does not exist.
+            `componentname__instanceid` or if the instance does not exist.
 
     Returns:
         Dict[str, Any]: The state of the component instance.
     """
     if "__" not in instance_name:
-        raise ValueError("Instance must be in the form `componentname__instancename`.")
+        raise ValueError("Instance must be in the form `componentname__instanceid`.")
 
     rp = RedisParams()
     redis_con = redis.Redis(host=rp.host, port=rp.port, password=rp.password, db=rp.db)
@@ -154,15 +154,11 @@ class CustomDict(dict):
 
 
 def validate_args(parameters: Any, op: str) -> bool:
-    expected_args = (
-        ["state", "values", "infer_results"] if op == "fit" else ["state", "value"]
-    )
-    if len(parameters) != len(expected_args):
+    if "state" not in parameters.keys():
         return False
 
-    for param_name, _ in parameters.items():
-        if param_name not in expected_args:
-            return False
+    if op == "update" and "serve_result" not in parameters.keys():
+        return False
 
     return True
 
@@ -228,8 +224,8 @@ def saveState(
     redis_con.incr(f"MOTION_VERSION:{instance_name}")
 
 
-class FitEvent:
-    """Waits for a fit operation to finish."""
+class UpdateEvent:
+    """Waits for a update operation to finish."""
 
     def __init__(self, redis_con: redis.Redis, channel: str, identifier: str) -> None:
         self.channel = channel
@@ -242,31 +238,37 @@ class FitEvent:
             if message["type"] != "message":
                 continue
 
-            error_data = eval(message["data"])
-            identifier = error_data["identifier"]
-            exception_str = error_data["exception"]
+            message_data_str = message["data"].decode("utf-8")
+            if message_data_str[0] == "{":
+                error_data = eval(message["data"])
+                identifier = error_data["identifier"]
+                exception_str = error_data["exception"]
 
-            if identifier != self.identifier:
-                continue
+                if identifier != self.identifier:
+                    continue
 
-            if exception_str:
-                raise RuntimeError(exception_str)
+                if exception_str:
+                    raise RuntimeError(exception_str)
 
-            break
+                break
+
+            else:
+                if message_data_str == self.identifier:
+                    break
 
 
-class FitEventGroup:
-    """Stores the events for fit operations on a given key."""
+class UpdateEventGroup:
+    """Stores the events for update operations on a given key."""
 
     def __init__(self, key: str) -> None:
         self.key = key
-        self.events: Dict[str, FitEvent] = {}
+        self.events: Dict[str, UpdateEvent] = {}
 
-    def add(self, udf_name: str, event: FitEvent) -> None:
+    def add(self, udf_name: str, event: UpdateEvent) -> None:
         self.events[udf_name] = event
 
     def wait(self) -> None:
-        """Waits for all fit operations for this dataflow key
+        """Waits for all update operations for this dataflow key
         to finish. Be careful not to trigger an infinite wait if the batch_size
         has not been hit yet!
 
@@ -280,17 +282,17 @@ class FitEventGroup:
         def setUp():
             return {"state_val": 0, "state_val2": 0}
 
-        @c.fit("my_key")
-        def fit1(state, values, infer_results):
+        @c.update("my_key")
+        def fit1(state, values, serve_results):
             return {"state_val": state["state_val"] + sum(values)}
 
-        @c.fit("my_key")
-        def fit2(state, values, infer_results):
+        @c.update("my_key")
+        def fit2(state, values, serve_results):
             return {"state_val2": state["state_val2"] + sum(values)}
 
         result, fit_tasks = c.run(my_key=1)
-        print(result) # None because no infer op was hit
-        fit_tasks.wait() # Wait for all fit tasks to finish
+        print(result) # None because no serve op was hit
+        fit_tasks.wait() # Wait for all update tasks to finish
         # Now `state["state_val"] = 1` and `state["state_val2"] = 1`
         ```
         """
@@ -298,7 +300,7 @@ class FitEventGroup:
             event.wait()
 
     def __str__(self) -> str:
-        return f"FitEventGroup(key={self.key}, events={self.events})"
+        return f"UpdateEventGroup(key={self.key}, events={self.events})"
 
     def __repr__(self) -> str:
         return self.__str__()
